# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class DtoTopUpWalletRequest(BaseModel):
    """
    DtoTopUpWalletRequest
    """ # noqa: E501
    amount: Union[StrictFloat, StrictInt] = Field(description="amount is the number of credits to add to the wallet")
    description: Optional[StrictStr] = Field(default=None, description="description to add any specific details about the transaction")
    expiry_date: Optional[StrictInt] = Field(default=None, description="expiry_date YYYYMMDD format in UTC timezone (optional to set nil means no expiry) for ex 20250101 means the credits will expire on 2025-01-01 00:00:00 UTC hence they will be available for use until 2024-12-31 23:59:59 UTC")
    generate_invoice: Optional[StrictBool] = Field(default=None, description="generate_invoice when true, an invoice will be generated for the transaction")
    metadata: Optional[Dict[str, StrictStr]] = None
    purchased_credits: Optional[StrictBool] = Field(default=None, description="purchased_credits when true, the credits are added as purchased credits")
    reference_id: Optional[StrictStr] = Field(default=None, description="reference_id is the ID of the reference ex payment ID, invoice ID, request ID")
    reference_type: Optional[StrictStr] = Field(default=None, description="reference_type is the type of the reference ex payment, invoice, request")
    __properties: ClassVar[List[str]] = ["amount", "description", "expiry_date", "generate_invoice", "metadata", "purchased_credits", "reference_id", "reference_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DtoTopUpWalletRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DtoTopUpWalletRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "description": obj.get("description"),
            "expiry_date": obj.get("expiry_date"),
            "generate_invoice": obj.get("generate_invoice"),
            "metadata": obj.get("metadata"),
            "purchased_credits": obj.get("purchased_credits"),
            "reference_id": obj.get("reference_id"),
            "reference_type": obj.get("reference_type")
        })
        return _obj





# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TypesPaymentMethodType(str, Enum):
    """
    TypesPaymentMethodType
    """

    """
    allowed enum values
    """
    CARD = 'CARD'
    ACH = 'ACH'
    OFFLINE = 'OFFLINE'
    CREDITS = 'CREDITS'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TypesPaymentMethodType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TypesTaskStatus(str, Enum):
    """
    TypesTaskStatus
    """

    """
    allowed enum values
    """
    PENDING = 'PENDING'
    PROCESSING = 'PROCESSING'
    COMPLETED = 'COMPLETED'
    FAILED = 'FAILED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TypesTaskStatus from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class DtoInvoiceLineItemResponse(BaseModel):
    """
    DtoInvoiceLineItemResponse
    """ # noqa: E501
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    created_at: Optional[StrictStr] = None
    created_by: Optional[StrictStr] = None
    currency: Optional[StrictStr] = None
    customer_id: Optional[StrictStr] = None
    display_name: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    invoice_id: Optional[StrictStr] = None
    metadata: Optional[Dict[str, StrictStr]] = None
    meter_display_name: Optional[StrictStr] = None
    meter_id: Optional[StrictStr] = None
    period_end: Optional[StrictStr] = None
    period_start: Optional[StrictStr] = None
    plan_display_name: Optional[StrictStr] = None
    plan_id: Optional[StrictStr] = None
    price_id: Optional[StrictStr] = None
    price_type: Optional[StrictStr] = None
    quantity: Optional[Union[StrictFloat, StrictInt]] = None
    status: Optional[StrictStr] = None
    subscription_id: Optional[StrictStr] = None
    tenant_id: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["amount", "created_at", "created_by", "currency", "customer_id", "display_name", "id", "invoice_id", "metadata", "meter_display_name", "meter_id", "period_end", "period_start", "plan_display_name", "plan_id", "price_id", "price_type", "quantity", "status", "subscription_id", "tenant_id", "updated_at", "updated_by"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DtoInvoiceLineItemResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DtoInvoiceLineItemResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "created_at": obj.get("created_at"),
            "created_by": obj.get("created_by"),
            "currency": obj.get("currency"),
            "customer_id": obj.get("customer_id"),
            "display_name": obj.get("display_name"),
            "id": obj.get("id"),
            "invoice_id": obj.get("invoice_id"),
            "metadata": obj.get("metadata"),
            "meter_display_name": obj.get("meter_display_name"),
            "meter_id": obj.get("meter_id"),
            "period_end": obj.get("period_end"),
            "period_start": obj.get("period_start"),
            "plan_display_name": obj.get("plan_display_name"),
            "plan_id": obj.get("plan_id"),
            "price_id": obj.get("price_id"),
            "price_type": obj.get("price_type"),
            "quantity": obj.get("quantity"),
            "status": obj.get("status"),
            "subscription_id": obj.get("subscription_id"),
            "tenant_id": obj.get("tenant_id"),
            "updated_at": obj.get("updated_at"),
            "updated_by": obj.get("updated_by")
        })
        return _obj


